.. image:: https://img.shields.io/pypi/v/vr.imager.svg
   :target: https://pypi.org/project/vr.imager

.. image:: https://img.shields.io/pypi/pyversions/vr.imager.svg

.. image:: https://img.shields.io/travis/yougov/vr.imager/master.svg
   :target: https://travis-ci.org/yougov/vr.imager

vr.imager is a component of the `Velociraptor
<https://github.com/yougov/velociraptor>`_ project.

The supported interface is the command-line API, invoked with
``vimage`` or ``python -m vr.imager``.
